boolean

package
v0.8.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 14, 2023 License: MIT Imports: 2 Imported by: 0

Documentation

Overview

Package boolean defines the interface for oh types that have a boolean value.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Value

func Value(c cell.I) bool

Value returns the boolean value for a cell.

Types

type I

type I interface {
	Bool() bool
}

I (boolean) is anything that evaluates to a true or false value.

Jump to