package
Version:
v0.8.3
Opens a new window with list of versions in this module.
Published: Sep 14, 2023
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package boolean defines the interface for oh types that have a boolean value.
Value returns the boolean value for a cell.
type I interface {
Bool() bool
}
I (boolean) is anything that evaluates to a true or false value.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.